// *********************************************************
// Persistence Of Vision Ray Tracer Scene Description File
// File name  : test.pov
// Version    : 3.6.1
// Description: test scene for the proceduralize() macro
// Date       : Apr. 2005
// Author     : Jaime Vives Piqueres
// Note	      : image maps not included, please use your own
// *********************************************************

#include "colors.inc"
#include "textures.inc"
#include "stones.inc"
#include "metals.inc"
#include "woods.inc"
#include "functions.inc"

// *** control center ***
#declare use_blur =7*0;  // blur samples (0=off)
#declare use_area   =0;
#declare use_radiosity =2;
#declare rad_brightness=1;
global_settings{
// assumed_gamma 1.0
 #if (use_radiosity)
  #include "i_rad.inc"
 #end
}
#default{texture{finish{ambient 0}}}

// *** MACRO TO PROCEDURALIZE PHOTOGRAPHIC TEXTURES ***
#include "proceduralize.inc"


// *** PROCEDURALIZED TEST TEXTURES ***
#if (use_radiosity<2)    
// metal
// image map not included, please use your own
#declare img_name="PA200178.JPG" 
#declare img_mapping=0;
#declare img_scale=12;
#declare img_filter=0;
#declare img_transmit=0.5;
#declare bump_size_1=-pi;
#declare bump_size_2=-pi;
#declare finish_1=finish{specular .33 diffuse .67 metallic}
//#declare finish_2=finish{specular .33 metallic reflection{.01,.33} diffuse .33}
#declare finish_2=finish{reflection{1} diffuse 0}
#declare change_point=.1;
#declare change_width=.9;
#declare img_turb=.1;
#declare img_lambda=5;
#declare t_base=texture{pigment{Brass*.5+Gray20}}
#declare t_metal=
texture{
 Proceduralize(
  img_name,img_mapping,
  img_filter,img_transmit,
  finish_1,finish_2,
  bump_size_1,bump_size_2,
  img_scale,
  change_point,change_width,
  img_turb,img_lambda,
  t_base
 )
}
// wood
// image map not included, please use your own
#declare img_name="P7143300.JPG" 
#declare img_mapping=0;
#declare img_scale=2.1;
#declare img_filter=.33;
#declare img_transmit=.33;
#declare bump_size_1=-10;
#declare bump_size_2=-10;
#declare finish_1=finish{diffuse 1}
#declare finish_2=finish{Glossy ambient 0}
#declare change_point=.8;
#declare change_width=.0;
#declare img_turb=<.01,.01,1>;
#declare img_lambda=0;
#declare t_base=texture{T_Wood2 rotate 90*x scale img_scale/4 finish{ambient 0}}
#declare t_wood=
texture{
 Proceduralize(
  img_name,img_mapping,
  img_filter,img_transmit,
  finish_1,finish_2,
  bump_size_1,bump_size_2,
  img_scale,
  change_point,change_width,
  img_turb,img_lambda,
  t_base
 )
}
// stone
// image map not included, please use your own
#declare img_name="PA180081.JPG" 
#declare img_mapping=0;
#declare img_scale=3;
#declare img_filter=.1;
#declare img_transmit=.1;
#declare bump_size_1=-pi;
#declare bump_size_2=-pi;
#declare finish_1=finish{}
#declare finish_2=finish{Dull ambient 0}
#declare change_point=.9;
#declare change_width=.1;
#declare img_turb=<.33,.33,1>;
#declare img_lambda=3;
#declare t_base=texture{T_Grnt1 rotate 90*x scale 1/img_scale finish{ambient 0}}
#declare t_stone=
texture{
 Proceduralize(
  img_name,img_mapping,
  img_filter,img_transmit,
  finish_1,finish_2,
  bump_size_1,bump_size_2,
  img_scale,
  change_point,change_width,
  img_turb,img_lambda,
  t_base
 )
}
#else
#declare t_metal=texture{pigment{SteelBlue*.5+Gray20}}
#declare t_wood=texture{pigment{Tan}}
#declare t_stone=texture{pigment{Gray}}
#end


// *** TEST OBJECT ***
superellipsoid{<.25,.25> rotate 90*x
 texture{t_stone} 
 scale <10,10,1>
 translate <0,1,10>
}
superellipsoid{<.25,.25> rotate 90*x
 texture{t_stone} 
 scale <10,10,1>
 rotate 90*y
 translate <-10,1,0>
}
superellipsoid{<.25,.25> rotate 90*x
 texture{t_wood} 
 scale <20,20,1>
 rotate 90*x
 translate -6*y
}
sphere{0,.5
 texture{t_metal} 
 scale 10
}


// *** RANDOM TEST LIGHTS ***
#declare r_l=seed(130); 
#declare lc=White+Blue*.1;
union{
 light_source{
  0,lc*2
  #if (use_area)
  area_light <12,0,0>,<0,0,12>,4,4 jitter adaptive 1 orient circular
  #end
  fade_distance 100 fade_power 2
 }
 sphere{0,1 hollow
  pigment { color rgbf<1, 1, 1, 1> }
  finish { ambient 0 diffuse 0 }
  interior{media{emission lc}}
  scale <2,3,2>
 }
 translate <-200+400*rand(r_l),110,-200+400*rand(r_l)>
}
#declare lc=White+Gold*.1;
union{
 light_source{
  0,lc*2
  #if (use_area)
  area_light <12,0,0>,<0,0,12>,4,4 jitter adaptive 1 orient circular
  #end
  fade_distance 100 fade_power 2
 }
 sphere{0,1 hollow
  pigment { color rgbf<1, 1, 1, 1> }
  finish { ambient 0 diffuse 0 }
  interior{media{emission lc}}
  scale <2,3,2>
 }
 translate <-200+400*rand(r_l),110,-200+400*rand(r_l)>
}


// *** ROOM ***
box{-.5,.5 scale <500,250,500>
 pigment{brick color White color Wheat scale 4}
 finish{diffuse 1}
}
plane{y,-124 pigment{checker color White color Gray10 scale 30}}
plane{y, 124 pigment{White}}


// **************
// *** camera ***
// **************
#declare cl=<38,12,-52>;
#declare la=<0,0,0>;
camera{
 location cl
 up 2.4*y
 right 3.2*x
 direction 8.5*z
 look_at la
 #if (use_blur)
 focal_point la
 aperture pi/2
 blur_samples use_blur
 #end
}

